#!/bin/sh
#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2013. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

binDir=`dirname "$0"`
. "$binDir"/setupCmdLine.sh
cd "$binDir"/../

#Platform specific args...
PLATFORM=`/bin/uname`
case $PLATFORM in
  AIX)
    CONSOLE_ENCODING=-Dws.output.encoding=console;;
  Linux)
    CONSOLE_ENCODING=-Dws.output.encoding=console;;
  SunOS)
    CONSOLE_ENCODING=-Dws.output.encoding=console;;
  HP-UX)
    CONSOLE_ENCODING=-Dws.output.encoding=console;;
  OS/390)
    EXTRA_D_ARG=-Dfile.encoding=ISO8859-1
    EXTRA_X_ARG=-Xnoargsconversion ;;
esac

# Set java options for performance
PLATFORM=`/bin/uname`
case $PLATFORM in
  AIX)
      PERF_JVM_OPTIONS="-Xms512m -Xmx768m -Xquickstart" ;;
  Linux)
      PERF_JVM_OPTIONS="-Xms512m -Xmx768m -Xj9 -Xquickstart" ;;
  SunOS)
      PERF_JVM_OPTIONS="-Xms512m -Xmx768m -XX:PermSize=40m -XX:MaxPermSize=256m -XX:+UnlockDiagnosticVMOptions -XX:+UnsyncloadClass" ;;
  HP-UX)
      PERF_JVM_OPTIONS="-Xms512m -Xmx768m -XX:PermSize=40m -XX:MaxPermSize=128m -XX:+UnlockDiagnosticVMOptions -XX:+UnsyncloadClass" ;;
  OS/390)
      PERF_JVM_OPTIONS="-Xms512m -Xmx768m" ;;
esac 

LOGGING_PROPS=-Djava.util.logging.config.file="$WAS_HOME/util/migration/resources/logging.properties"
LOGGING_FILTER_PROP="-Dcom.ibm.bpm.migration.logging.StringFilter.excludes=equals(WSVR0072W);equals(WSVR0801I);equals(WKSP0500);equals(CWWMH0110E);equals(ADMC0046W);equals(SIB_MESSAGE);equals(SOME_FUTURE_MESSAGES_SUPPRESSED_CWSIU0005);equals(chain.started);contains(tmx4jTransform.jar)"

SSL_PROPS=-Dcom.ibm.SSL.ConfigURL=file:///$WAS_HOME/util/migration/resources/ssl.client.props
SOAP_CLIENT_PROPS=-Dcom.ibm.SOAP.ConfigURL=file:///$WAS_HOME/util/migration/resources/soap.client.props

COMMAND_NAME=`basename $0`
COMMAND_NAME="${COMMAND_NAME%.*}"
COMMAND_NAME_PROPS=-Dmig.command.name="${COMMAND_NAME}"

PARAMS="$@"
while [ $# -gt 0 ]; do
  if [ $1 = "-reportDir" ];
  then
        reportDir=$2;
        break;
  else
        shift;
  fi
done
REPORT_DIR_PROPS=-Dmig.snapshot.root="$reportDir"

ENABLE_DEBUG=false
if [ $ENABLE_DEBUG = true ]; then
   DEBUG_PROP="-agentlib:jdwp=transport=dt_socket,server=y,suspend=y,address=9999"
else
   DEBUG_PROP=
fi


"$JAVA_HOME/bin/java" \
  "$OSGI_INSTALL" "$OSGI_CFG" \
  $EXTRA_X_ARG \
  $DEBUG_PROP \
  $CONSOLE_ENCODING \
  $LOGGING_PROPS \
  $LOGGING_FILTER_PROP \
  $SSL_PROPS \
  $SOAP_CLIENT_PROPS \
  $COMMAND_NAME_PROPS \
  -Dws.ext.dirs="$WAS_EXT_DIRS" \
  -Djava.endorsed.dirs="$WAS_ENDORSED_DIRS" \
  -Dwas.install.root="$WAS_HOME" \
  $PERF_JVM_OPTIONS \
  ${JAASSOAP:+"$JAASSOAP"} \
  $EXTRA_D_ARG \
  $JVM_EXTRA_CMD_ARGS \
  -classpath "$WAS_CLASSPATH":"$WAS_HOME"/lib/j2ee.jar:"$WAS_HOME"/properties:"$WAS_HOME"/BPM/Lombardi/lib/xbean.jar:"$WAS_HOME"/plugins/com.ibm.bpm.migration.logging.jar com.ibm.wsspi.bootstrap.WSPreLauncher \
  -nosplash -application com.ibm.ws.bootstrap.WSLauncher com.ibm.bpm.migration.validation.BPMPreValidation -preValidation $PARAMS
  
exit $?
